# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-File-HomeDir
Version:	1.006
Release:	9.%{__distinit}%{__distvers}
Summary:	Find your home and other directories on any platform
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/File-HomeDir
Source0:	https://cpan.metacpan.org/modules/by-module/File/File-HomeDir-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(POSIX)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd) >= 3.12
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Path) >= 2.01
BuildRequires:	perl(File::Spec) >= 3.12
BuildRequires:	perl(File::Temp) >= 0.19
BuildRequires:	perl(File::Which) >= 0.05
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Test::More) >= 0.90
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Path) >= 2.01

%description
File::HomeDir is a module for locating the directories that are "owned"
by a user (typically your user) and to solve the various issues that
arise trying to find them consistently across a wide variety of
platforms.

%prep
%setup -q -n File-HomeDir-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README.md
%{perl_vendorlib}/File/
%{_mandir}/man3/File::HomeDir.3*
%{_mandir}/man3/File::HomeDir::Darwin.3*
%{_mandir}/man3/File::HomeDir::Darwin::Carbon.3*
%{_mandir}/man3/File::HomeDir::Darwin::Cocoa.3*
%{_mandir}/man3/File::HomeDir::Driver.3*
%{_mandir}/man3/File::HomeDir::FreeDesktop.3*
%{_mandir}/man3/File::HomeDir::MacOS9.3*
%{_mandir}/man3/File::HomeDir::Test.3*
%{_mandir}/man3/File::HomeDir::Unix.3*
%{_mandir}/man3/File::HomeDir::Windows.3*

%changelog
* Thu Jun  1 2023 Paul Howarth <paul@city-fan.org> - 1.006-9
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop support for building with rpm < 4.9

* Mon Sep 28 2020 Paul Howarth <paul@city-fan.org> - 1.006-1
- Update to 1.006
  - Re-release with minor fixes to cover modern toolchain
  - Fix running on Perl 5.8.3 (CPAN RT#128096)

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 1.004-5
- Perl 5.30 rebuild

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.004-2
- Perl 5.28 rebuild

* Wed May  2 2018 Paul Howarth <paul@city-fan.org> - 1.004-1
- Update to 1.004
  - Skip root homedir test for cygwin (CPAN RT#104661)
  - Document even undocumented fetchers for FreeDesktop implementation
    (CPAN RT#103305) and status quo (CPAN RT#88681)
  - Fix several typos (CPAN RT#86426, CPAN RT#67093, GH#1)
  - Play with https://coveralls.io/
  - Remove tie interface (GH#4)
  - Determine ->my_home when $ENV{HOME} is empty (based on GH#3)
  - Relocate repository
  - Build distribution on Linux
  - Add debug message because of CPAN RT#65301
  - Run author tests with installed spell-checker
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Fri Apr  7 2017 Paul Howarth <paul@city-fan.org> - 1.002-1
- Update to 1.002
  - Switch to ExtUtils::MakeMaker
  - Compatibility with blead
- This release by REHSACK → update source URL
- Drop POD encoding patch, no longer needed
- Upstream dropped extra tests
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Aug 24 2016 Paul Howarth <paul@city-fan.org> - 1.00-12
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 1.00-7
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Oct 22 2012 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - No functional changes
  - Updating to Module::Install 1.06
  - Don't require documents directory on Mac under AUTOMATED_TESTING

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.99-3
- Perl 5.16 post-bootstrap rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.99-2
- BR:/R: perl(Exporter)
- BR: perl(File::Spec::Functions)
- Add missing POD encoding that causes POD test to fail
- Drop buildreq perl(Config) as it's not dual-lived
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jan 25 2012 Paul Howarth <paul@city-fan.org> - 0.99-1
- Update to 0.99
  - Updated to Module::Install 1.04
  - Removed deprecated interfaces from the documentation
  - Don't require music and video directories in FreeDesktop tests
  - The use of deprecated %%~ now emits a warning
- BR: perl(Config)

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 0.98-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98
  - Updating to Module::Install 1.01
  - If Win32::GetFolderPath returns a \\UNC type path, do not do the normal -d
    sanity check, as strange and unusual bugs may occur
- Nobody else likes macros for commands

* Fri Mar 18 2011 Paul Howarth <paul@city-fan.org> - 0.97-2
- Import from Fedora

* Mon Feb 21 2011 Tom Callaway <spot@fedoraproject.org> - 0.97-1
- Update to 0.97

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.93-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 16 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.93-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Wed Sep 22 2010 Petr Pisar <ppisar@redhat.com> - 0.93-1
- 0.93 bump
- Consolidate dependencies
- Remove unversioned Requires
- Update Summary and Description
- Remove unneeded file permission fixes

* Sat May 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.86-4
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.86-3
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.86-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun  1 2009 Marcela Mašláňová <mmaslano@redhat.com> - 0.86-1
- Update for Padre

* Fri Mar 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.84-1
- Update to 0.84

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.82-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 16 2008 Marcela Mašláňová <mmaslano@redhat.com> - 0.82-1
- Update to the latest version for Padre editor

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.67-3
- Rebuild for perl 5.10 (again)

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.67-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.67-1
- 0.67

* Fri Nov 30 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.66-1
- 0.66

* Wed May 30 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.65-1
- Update to 0.65

* Sat Feb 10 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.64-1
- Update to 0.64

* Thu Jan 11 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.63-1
- Update to 0.63

* Thu Jan  4 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.62-1
- Update to 0.62

* Thu Aug 03 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.58-1
- First build
